# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""fix dag deliver templates

Revision ID: d414629d8ee8
Revises: 91f96bd53b5b
Create Date: 2021-10-25 14:34:49.974422

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "d414629d8ee8"
down_revision = "91f96bd53b5b"
branch_labels = None
depends_on = None


restore_script = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

mv $2/working/{{sdmId}}.ms $2/products/
./deliver -p $2/products --prefix $1

"""

restore_condor = """executable = restore_cms_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_deliver.out
error = restore_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

img_script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./deliver -p $2/products --prefix $1

"""

img_condor = """executable = std_restore_imaging_deliver.sh
arguments = {{request_id}} {{spool_dir}}

output = restore_img_deliver.out
error = restore_img_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

old_restore_script = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

cp -r ./working/{{sdmId}}.ms ./products/
./deliver -p ./products --prefix $1

"""

old_restore_condor = """executable = restore_cms_deliver.sh
arguments = {{request_id}}

output = restore_deliver.out
error = restore_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver, ./products, ./working

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

old_img_script = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./deliver -p ./products --prefix $1

"""

old_img_condor = """executable = std_restore_imaging_deliver.sh
arguments = {{request_id}}

output = restore_img_deliver.out
error = restore_img_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver, ./products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_script}' WHERE filename='restore_cms_deliver.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_condor}' WHERE filename='restore_cms_deliver.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{img_script}' WHERE filename='std_restore_imaging_deliver.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{img_condor}' WHERE filename='std_restore_imaging_deliver.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_script}' WHERE filename='restore_cms_deliver.sh'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_restore_condor}' WHERE filename='restore_cms_deliver.condor'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_img_script}' WHERE filename='std_restore_imaging_deliver.sh'
            """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_img_condor}' WHERE filename='std_restore_imaging_deliver.condor'
            """
    )
